USE [master];
GO

IF DATABASEPROPERTYEX('ClientsDB', 'Version') IS NOT NULL
BEGIN
	ALTER DATABASE [ClientsDB]
	SET SINGLE_USER 
	WITH ROLLBACK IMMEDIATE;

	DROP DATABASE [ClientsDB];
END

CREATE DATABASE [ClientsDB]
ON PRIMARY 
( NAME = N'ClientsDB', FILENAME = N'C:\Data\ClientsDB.mdf', SIZE = 5120KB, MAXSIZE = UNLIMITED, FILEGROWTH = 1024KB )
LOG ON 
( NAME = N'ClientsDB_log', FILENAME = N'C:\Data\ClientsDB_log.ldf', SIZE = 2048KB, MAXSIZE = 2048GB, FILEGROWTH = 10%);
GO

USE [ClientsDB]
GO

CREATE TABLE [dbo].[Clients] (
    [ClientGuid]         UNIQUEIDENTIFIER NOT NULL,
    [ClientName]         NVARCHAR (50)    NOT NULL,
    [ClientEmailAddress] VARCHAR (50)     NULL,
    [ClientPhoneNumber]  VARCHAR (20)     NULL,
    CONSTRAINT [PK_Clients] PRIMARY KEY CLUSTERED ([ClientGuid] ASC),
    CONSTRAINT [CK_Clients_ClientName_Length] CHECK (len([ClientName]) > (9))
);
GO

INSERT [dbo].[Clients] ([ClientGuid], [ClientName], [ClientEmailAddress], [ClientPhoneNumber]) 
VALUES 
	(N'83fcd0b9-989e-40ba-b114-41e3a4a5c2c1', N'Peter Woods', N'PeterW@company.com', NULL),
	(N'48c4379e-f6c6-4519-be55-5ba03e893a9e', N'Anna Smith', N'AnnaS@company.com', NULL),
	(N'f9a4b8d9-2324-415e-8fbe-5c3ebefbcda6', N'Lee San Wu', N'LeeW@company.com', NULL),
	(N'6f045aa4-e1ac-4f17-8417-c0dfcaaaba11', N'Michael Jones', N'MichaelJ@company.com', NULL);
GO

CREATE PROCEDURE [dbo].[CreateClient]
	@ClientGuid uniqueidentifier,
	@ClientName nvarchar(50),
	@ClientEmailAddress varchar(50),
	@ClientPhoneNumber varchar(20)
AS
BEGIN
	SET NOCOUNT ON;

	INSERT INTO dbo.Clients (
		ClientGuid,
		ClientName,
		ClientEmailAddress,
		ClientPhoneNumber
		)
	VALUES (
		@ClientGuid,
		@ClientName,
		@ClientEmailAddress,
		@ClientPhoneNumber
		);		
END
GO

CREATE PROCEDURE [dbo].[FindClientsByName]
	@Name nvarchar(50)
AS
BEGIN
	SET NOCOUNT ON;

	SELECT 
		ClientGuid, 
		ClientName, 
		ClientPhoneNumber
	FROM Clients
	WHERE ClientName LIKE '%' + ISNULL(@Name, '') + '%';

END
GO
